==> lb_plus-3.1.0.tar.gz: lb_plus/src/Controller/LbPlusUi.php <==
<?php

declare(strict_types=1);

namespace Drupal\lb_plus\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\lb_plus\LbPlusRebuildTrait;
use Drupal\lb_plus\SectionStorageHandler;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Drupal\lb_plus\Element\LayoutBuilderPlusUI;
use Drupal\layout_builder\SectionStorageInterface;
use Drupal\toolbar_plus\Controller\LoadEditablePage;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Layout Builder + routes.
 */
final class LbPlusUi extends ControllerBase {

  use LbPlusRebuildTrait;

  public function __construct(
    private readonly SectionStorageHandler $lbPlusSectionStorageHandler,
  ) {}

  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('lb_plus.section_storage_handler'),
    );
  }

  /**
   * Builds the response.
   */
  public function enabledLayoutMode(Request $request, SectionStorageInterface $section_storage): AjaxResponse {

    $response = new AjaxResponse();
    $layout = [
      '#type' => 'layout_builder_plus',
      '#section_storage' => $section_storage,
    ];
    $entity = $section_storage->getContextValue('entity');
    $view_mode = $section_storage->getContextValue('view_mode');

    // @todo Put the entity specific selector in a form some where.
    $config_name = sprintf('core.entity_view_display.%s.%s.%s',
      $entity->getEntityTypeId(),
      $entity->bundle(),
      $view_mode
    );

    $entity_specific_selector = $this->config($config_name)->get('third_party_settings.lb_plus.ui_selector') ?? '.node__content';
    $selector = "[data-toolbar-plus-entity-wrapper='{$entity->getEntityTypeId()}::{$entity->id()}::{$entity->bundle()}'] $entity_specific_selector";

    $response->addCommand(new ReplaceCommand($selector, $layout));

    // Build the sidebar.
    $page_bottom = [];
    \Drupal::classResolver(LayoutBuilderPlusUI::class)->build($page_bottom);
    $response->addCommand(new ReplaceCommand('#lb_plus-left-sidebar', $page_bottom));

    return $response;
  }

  public function disableLayoutMode(Request $request, SectionStorageInterface $section_storage, string $view_mode): AjaxResponse {
    $entity = $section_storage->getContextValue('entity');
    return \Drupal::classResolver(LoadEditablePage::class)->__invoke($entity, $view_mode);
  }

}

==> lb_plus-3.1.1.tar.gz: lb_plus/src/Controller/LbPlusUi.php <==
<?php

declare(strict_types=1);

namespace Drupal\lb_plus\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\lb_plus\LbPlusRebuildTrait;
use Drupal\lb_plus\SectionStorageHandler;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Drupal\lb_plus\Element\LayoutBuilderPlusUI;
use Drupal\layout_builder\SectionStorageInterface;
use Drupal\navigation_plus\Controller\LoadEditablePage;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Layout Builder + routes.
 */
final class LbPlusUi extends ControllerBase {

  use LbPlusRebuildTrait;

  public function __construct(
    private readonly SectionStorageHandler $lbPlusSectionStorageHandler,
  ) {}

  public static function create(ContainerInterface $container): self {
    return new self(
      $container->get('lb_plus.section_storage_handler'),
    );
  }

  /**
   * Builds the response.
   */
  public function enabledLayoutMode(Request $request, SectionStorageInterface $section_storage): AjaxResponse {

    $response = new AjaxResponse();
    $layout = [
      '#type' => 'layout_builder_plus',
      '#section_storage' => $section_storage,
    ];
    $entity = $section_storage->getContextValue('entity');
    $view_mode = $section_storage->getContextValue('view_mode');

    // @todo Put the entity specific selector in a form some where.
    $config_name = sprintf('core.entity_view_display.%s.%s.%s',
      $entity->getEntityTypeId(),
      $entity->bundle(),
      $view_mode
    );

    $entity_specific_selector = $this->config($config_name)->get('third_party_settings.lb_plus.ui_selector') ?? '.node__content';
    $selector = "[data-navigation-plus-entity-wrapper='{$entity->getEntityTypeId()}::{$entity->id()}::{$entity->bundle()}'] $entity_specific_selector";

    $response->addCommand(new ReplaceCommand($selector, $layout));

    // Build the sidebar.
    $page_bottom = [];
    \Drupal::classResolver(LayoutBuilderPlusUI::class)->build($page_bottom);
    $response->addCommand(new ReplaceCommand('#lb_plus-left-sidebar', $page_bottom));

    return $response;
  }

  public function disableLayoutMode(Request $request, SectionStorageInterface $section_storage, string $view_mode): AjaxResponse {
    $entity = $section_storage->getContextValue('entity');
    return \Drupal::classResolver(LoadEditablePage::class)->__invoke($entity, $view_mode);
  }

}
